@@ -16,10 +16,10 @@
  *
  * The Initial Developer of the Original Code is
  * Mozilla Foundation.
- * Portions created by the Initial Developer are Copyright (C) 2008
+ * Portions created by the Initial Developer are Copyright (C) 2007
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Jesse Ruderman
+ * Contributor(s): moz_bug_r_a4
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,20 +35,40 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-455464-01.js';
+var gTestfile = 'regress-367118-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 455464;
-var summary = 'Do not assert with JIT: !TRACE_RECORDER(cx) ^ (jumpTable == recordingJumpTable)';
+var BUGNUMBER = 367118;
+var summary = 'memory corruption in script_compile';
 var actual = 'No Crash';
 var expect = 'No Crash';
 
-printBugNumber(BUGNUMBER);
-printStatus (summary);
+//-----------------------------------------------------------------------------
+test();
+//-----------------------------------------------------------------------------
 
-jit(true);
+function test()
+{
+  enterFunc ('test');
+  printBugNumber(BUGNUMBER);
+  printStatus (summary);
+ 
+  if (typeof Script == 'undefined')
+  {
+    print('Test skipped. Script or toSource not defined');
+  }
+  else
+  {
+    var s = new Script("");
+    var o = {
+      toString : function() {
+        s.compile("");
+        print(1);
+        return "a";
+      }
+    };
+    s.compile(o);
+  }
+  reportCompare(expect, actual, summary);
 
-a=b=c=d=0; this.__defineGetter__('g', gc); for each (y in this);
-
-jit(false);
-
-reportCompare(expect, actual, summary);
+  exitFunc ('test');
+}
